#!/usr/bin/perl -w
#
# $Id: NetworkTree.pm,v 1.11 2003/06/11 06:05:20 solovam Exp $
#
# NetworkTree class
#
package NetworkTree;

use Gtk;
use strict;
use Misc;

#
# Constructor
#
sub new
{
	my $type = shift;
	my $gKismetApplication = shift;
	my $self = {};
	bless $self, $type;

	$self->{'gKismetApplication'} = $gKismetApplication;

	# Create ctree
	$self->{'ctree'} = new Gtk::CTree(2, 0);
	$self->{'ctree'}->set_column_auto_resize(0, $true);
	$self->{'ctree'}->set_column_auto_resize(1, $true);
	### $self->{'ctree'} = new_with_titles Gtk::CTree(0, '', '');
	### $self->{'ctree'}->set_column_width(0, 200);
	### $self->{'ctree'}->set_column_width(1, 200);
	$self->{'ctree'}->set_line_style('dotted');
	$self->{'ctree'}->set_indent(15); 
	$self->{'ctree'}->set_spacing(5);
	$self->{'ctree'}->show();

	# Get colors
        $self->buildColors();

	return $self;
}

#
# Destrcuctor
#
sub DESTROY
{
	my $self = shift;
	if(defined $self->getWidget())
	{
		$self->getWidget()->destroy();
	}
}

#
# Remove all stored data
#
sub flush
{
	my $self = shift;

	# Remove all nodes from Ctree
	for my $n (keys %{$self->{'cnode'}})
        {
                if(defined $self->{'cnode'}{$n}{'node'})
                {
                        $self->{'ctree'}->remove_node($self->{'cnode'}{$n}{'node'});
                }
        }

	# Delete cnodes hash
	delete $self->{'cnode'};
}

#
# Get widget
#
sub getWidget
{
	my $self = shift;
	return $self->{'ctree'};
}

#
# Connection data updated
#
sub update
{
	my $self = shift;
	my $connection = shift;
	my $data = shift;

	if($data->{'changed'} eq 'network')
	{
		$self->networkUpdate($connection, $data->{'bssid'});
	}
	elsif($data->{'changed'} eq 'client')
	{
		$self->clientUpdate($connection, $data->{'bssid'}, $data->{'mac'});
	}
	elsif($data->{'changed'} eq 'remove')
	{
		$self->networkRemove($connection, $data->{'bssid'});
	}
}

#
# Called when a network is updated or added
#
sub networkUpdate
{
	my $self = shift;
	my $connection = shift;
	my $bssid = shift;
	my $ctree = $self->{'ctree'};
	my $preferences = $self->{'gKismetApplication'}->{'preferences'};

	# If there is no network node create it
	if(!defined $self->{'cnode'}{$bssid}{'node'})
	{
		my $n = $ctree->insert_node(undef, undef, [$connection->getNetworkFieldValue('SSID', $bssid), ''], 5,  undef, undef, undef, undef, $false, $false);
		$ctree->node_set_foreground($n, $self->{'color' . $connection->getNetworkColor($bssid)});
		$ctree->node_set_selectable($n, $false);
		$self->{'cnode'}{$bssid}{'node'} = $n;
	}

	# Loop through the network fields
	for my $f ($preferences->getNetworkFieldNames())
	{
		# If the field is shown
		if($preferences->getNetworkFieldStatus($f))
		{
			# If the field node is not defined create it
			if(!defined $self->{'cnode'}{$bssid}{$f}{'node'})
			{
				my $n = $ctree->insert_node($self->{'cnode'}{$bssid}{'node'}, undef, [$f, $connection->getNetworkFieldValue($f, $bssid)],
					5, undef, undef, undef, undef, $true, $false); 
				$ctree->node_set_selectable($n, $false);
				$self->{'cnode'}{$bssid}{$f}{'node'} = $n;
			}
			# Update field node value
			$ctree->set_text($self->{'cnode'}{$bssid}{$f}{'node'}, 1, $connection->getNetworkFieldValue($f, $bssid));
		}
	}
}

#
# Called when a network is deleted
#
sub networkRemove
{
	my $self = shift;
	my $network = shift;
	my $bssid = shift;
	$self->{'ctree'}->remove_node($self->{'cnode'}{$bssid}{'node'});
	delete $self->{'cnode'}{$bssid};
}

#
# Called when a client is updated or added
#
sub clientUpdate
{
	my $self = shift;
	my $connection = shift;
	my $bssid = shift;
	my $mac = shift;
	my $ctree = $self->{'ctree'};
	my $preferences = $self->{'gKismetApplication'}->{'preferences'};

	# If client node is not defined create it
	if(!defined $self->{'cnode'}{$bssid}{'client'}{$mac}{'node'})
	{
		my $n = $ctree->insert_node($self->{'cnode'}{$bssid}{'node'}, undef, [$connection->getClientFieldValue('MAC', $bssid, $mac), ''], 5,  undef,
			undef, undef, undef, $false, $false);
		$self->{'cnode'}{$bssid}{'client'}{$mac}{'node'} = $n;
		$ctree->node_set_selectable($n, $false);
	}

	# Loop through client fields
	for my $f ($preferences->getClientFieldNames())
	{
		# If the field is shown
		if($preferences->getClientFieldStatus($f))
		{
			# If the client field is not defined create it
			if(!defined $self->{'cnode'}{$bssid}{'client'}{$mac}{$f}{'node'})
			{
				my $n = $ctree->insert_node($self->{'cnode'}{$bssid}{'client'}{$mac}{'node'}, undef,
					[$f, $connection->getClientFieldValue($f, $bssid, $mac)], 5, undef, undef, undef, undef, $true, $false);
				$self->{'cnode'}{$bssid}{'client'}{$mac}{$f}{'node'} = $n;
				$ctree->node_set_selectable($n, $false);
			}
			# Update client field node value
			$ctree->set_text($self->{'cnode'}{$bssid}{'client'}{$mac}{$f}{'node'}, 1, $connection->getClientFieldValue($f, $bssid, $mac));
		}
	}
}

#
# Get colors
#
sub buildColors
{
	my $self = shift;
	my $colormap = $self->{'ctree'}->get_colormap();

	my $colorYellow = Gtk::Gdk::Color->parse_color("yellow3");
	$colorYellow = $colormap->color_alloc($colorYellow);
	$self->{'colorYellow'} = $colorYellow;

	my $colorGreen = Gtk::Gdk::Color->parse_color("green2");
	$colorGreen = $colormap->color_alloc($colorGreen);
	$self->{'colorGreen'} = $colorGreen;

	my $colorRed = Gtk::Gdk::Color->parse_color("red2");
	$colorRed = $colormap->color_alloc($colorRed);
	$self->{'colorRed'} = $colorRed;

	my $colorBlack = Gtk::Gdk::Color->parse_color("black");
	$colorBlack = $colormap->color_alloc($colorBlack);
	$self->{'colorBlack'} = $colorBlack;
}

#
# Collapse tree
#
sub collapse
{
	my $self = shift;
	$self->{'ctree'}->collapse_recursive(undef);
}

#
# Expand tree
#
sub expand
{
	my $self = shift;
	$self->{'ctree'}->expand_recursive(undef);
}

1;
