#!/usr/bin/perl -w
#
# $Id: Preferences.pm,v 1.9 2003/06/11 04:12:26 solovam Exp $
#
# Preferences class
#
package Preferences;

use strict;
use Misc;

#
# Constructor
#
sub new
{
	my $type = shift;
	my $self = {};
	bless $self, $type;

	$self->{'networkFields'} =
		[
			{field => 'BSSID', show => 1},
			{field => 'Carrier', show => 1},
			{field => 'Manufacturer', show => 1},
			{field => 'Model', show => 1},
			{field => 'Max rate', show => 1},
			{field => 'First seen', show => 1},
			{field => 'Last seen', show => 1},
			{field => 'Clients', show => 1},
			{field => 'Type', show => 1},
			{field => 'Channel', show => 1},
			{field => 'WEP', show => 1},
			{field => 'Beacon',  show => 1},
			{field => 'Data packets', show => 1},
			{field => 'LLC packets', show => 1},
			{field => 'Crypt packets', show => 1},
			{field => 'Weak packets', show => 1},
			{field => 'Data', show => 1},
			{field => 'Quality', show => 1},
			{field => 'Power', show => 1},
			{field => 'Noise', show => 1},
			{field => 'IP Range', show => 1},
			{field => 'IP Type', show => 1}
		];
	for my $f (@{$self->{'networkFields'}})
	{
		$f->{'show'} = Gnome::Config->get_bool('/gkismet/networkFields/' . $f->{'field'} . '=true');
	}
	$self->{'clientFields'} =
		[
			{field => 'Type', show => 1},
			{field => 'Manufacturer', show => 1},
			{field => 'Model', show => 1},
			{field => 'First seen', show => 1},
			{field => 'Last seen', show => 1},	
			{field => 'Max rate', 'WEP', 'IP', show => 1},
			{field => 'Data packets', show => 1},
			{field => 'Crypt packets', show => 1},
			{field => 'Weak packets', show => 1},
			{field => 'Data', show => 1},
			{field => 'Quality', show => 1},
			{field => 'Power', show => 1},
			{field => 'Noise', show => 1}
		];
	for my $f (@{$self->{'clientFields'}})
	{
		$f->{'show'} = Gnome::Config->get_bool('/gkismet/clientFields/' . $f->{'field'} . '=true');
	}

	return $self;
}

#
# Save preferences
#
sub save
{
	my $self = shift;

	for my $f (@{$self->{'networkFields'}})
	{
		Gnome::Config->set_bool('/gkismet/networkFields/' . $f->{'field'}, $f->{'show'});
	}
	for my $f (@{$self->{'clientFields'}})
	{
		Gnome::Config->set_bool('/gkismet/clientFields/' . $f->{'field'}, $f->{'show'});
	}
	Gnome::Config->sync();
}

#
# Get list of network field names
#
sub getNetworkFieldNames
{
	my $self = shift;
	my @fieldNames;
	for my $f (@{$self->{'networkFields'}})
	{
		push @fieldNames, $f->{'field'};
	}
	return @fieldNames;
}

#
# Get list of client field names
#
sub getClientFieldNames
{
	my $self = shift;
	my @fieldNames;
	for my $f (@{$self->{'clientFields'}})
	{
		push @fieldNames, $f->{'field'};
	}
	return @fieldNames;
}

#
# Get status of a network field
#
sub getNetworkFieldStatus
{
	my $self = shift;
	my $field = shift;
	for my $f (@{$self->{'networkFields'}})
	{
		if($f->{'field'} eq $field)
		{
			return $f->{'show'};
		}
	}
	return 0;
}

#
# Set status of a network field
#
sub setNetworkFieldStatus
{
	my $self = shift;
	my $field = shift;
	my $status = shift;
	for my $f (@{$self->{'networkFields'}})
	{
		if($f->{'field'} eq $field)
		{
			$f->{'show'} = $status;
		}
	}
	return 0;
}

#
# Get status of a client field
#
sub getClientFieldStatus
{
	my $self = shift;
	my $field = shift;
	for my $f (@{$self->{'clientFields'}})
	{
		if($f->{'field'} eq $field)
		{
			return $f->{'show'};
		}
	}
	return 0;
}

#
# Set status of a client field
#
sub setClientFieldStatus
{
	my $self = shift;
	my $field = shift;
	my $status = shift;
	for my $f (@{$self->{'clientFields'}})
	{
		if($f->{'field'} eq $field)
		{
			$f->{'show'} = $status;
		}
	}
	return 0;
}

1;
