#!/usr/bin/perl
#
# $Id: PrefsDialog.pm,v 1.9 2003/06/11 04:17:25 solovam Exp $
#
# PrefsDialog class
#
package PrefsDialog;

use Gnome;
use strict;
use Misc;

#
# Constructor
#
sub new
{
	my $type = shift;
	my $self = {};
	bless $self, $type;

	my $gKismetApplication = shift;
	$self->{'gKismetApplication'} = $gKismetApplication;
	my $preferences = $gKismetApplication->{'preferences'};

	my $propertyBox = new Gnome::PropertyBox();
	$self->{'propertyBox'} = $propertyBox;
	$propertyBox->signal_connect('destroy', sub{$self->destroyHandler()});
	$propertyBox->signal_connect('apply', sub {$self->applyHandler()});
	$propertyBox->set_parent($gKismetApplication->getWidget());
	$propertyBox->show();

	my $nNetworkFields = scalar $preferences->getNetworkFieldNames();
	my $networkFrame = new Gtk::Frame('Network');
	my $networkTable = new Gtk::Table($nNetworkFields + 1, 2, $false);
	$networkFrame->add($networkTable);
	my $i = 0;
	for my $f ($preferences->getNetworkFieldNames())
	{
		my $button = new Gtk::CheckButton($f);
		if($preferences->getNetworkFieldStatus($f))
		{
			$button->set_active($true);
		}
		$self->{'networkFieldButton'}{$f} = $button;
		$button->signal_connect('clicked', sub {$self->clickedHandler()});
		if(!($i % 2))
		{
			$networkTable->attach($button, 0, 1, $i, $i + 1, 'fill', 'fill', 0, 0);
		}
		else
		{
			$networkTable->attach($button, 1, 2, $i - 1, $i, 'fill', 'fill', 0, 0);
		}
		$i++;
	}

	my $nClientFields = scalar $preferences->getClientFieldNames();
	my $clientFrame = new Gtk::Frame('Client');
	my $clientTable = new Gtk::Table($nClientFields + 1, 2, $false);
	$clientFrame->add($clientTable);
	$i = 0;
	for my $f ($preferences->getClientFieldNames())
	{
		my $button = new Gtk::CheckButton($f);
		if($preferences->getClientFieldStatus($f))
		{
			$button->set_active($true);
		}
		$self->{'clientFieldButton'}{$f} = $button;
		$button->signal_connect('clicked', sub {$self->clickedHandler()});
		if(!($i % 2))
		{
			$clientTable->attach($button, 0, 1, $i, $i + 1, 'fill', 'fill', 0, 0);
		}
		else
		{
			$clientTable->attach($button, 1, 2, $i - 1, $i, 'fill', 'fill', 0, 0);
		}

		$i++;
	}

	my $hbox = new Gtk::HBox($true, 0);

	$hbox->pack_start($networkFrame, $true, $false, 0);
	$hbox->pack_start($clientFrame, $true, $false, 0);

	my $tabLabel = new Gtk::Label('Fields');
	$propertyBox->append_page($hbox, $tabLabel);
	$propertyBox->show_all();

	return $self;
}

#
# Destructor
#
sub DESTROY
{
	my $self = shift;
	if(defined $self->getWidget())
	{
		$self->getWidget()->destroy();
	}
}

#
# Destroy handler
#
sub destroyHandler
{
	my $self = shift;
	$self->{'gKismetApplication'}->preferencesClose();
}

#
# Button handler
#
sub clickedHandler
{
	my $self = shift;
	$self->{'propertyBox'}->changed();
	return($false);
}

#
# Applied handler
#
sub applyHandler
{
	my $self = shift;
	my $preferences = $self->{'gKismetApplication'}->{'preferences'};

	for my $f ($preferences->getNetworkFieldNames())
	{
		if($self->{'networkFieldButton'}{$f}->get_active())
		{
			$preferences->setNetworkFieldStatus($f, 1);
		}
		else
		{
			$preferences->setNetworkFieldStatus($f, 0);
		}
	}

	for my $f ($preferences->getClientFieldNames())
	{
		if($self->{'clientFieldButton'}{$f}->get_active())
		{
			$preferences->setClientFieldStatus($f, 1);
		}
		else
		{
			$preferences->setClientFieldStatus($f, 0);
		}
	}

	$preferences->save();
	$self->{'gKismetApplication'}->preferencesUpdateNotify();
	return($false);
}

#
# Get widget
#
sub getWidget
{
	my $self = shift;
	return $self->{'propertyBox'};
}

1;
